==> cloudsnorkel.cdk_github_runners-0.10.3-py3-none-any.whl: package/assets/image-builders/aws-image-builder/reaper.lambda/index.js <==
"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));

// src/image-builders/aws-image-builder/reaper.lambda.ts
var AWS = __toESM(require("aws-sdk"));
var ec2 = new AWS.EC2();
var ecr = new AWS.ECR();
var ib = new AWS.Imagebuilder();
async function iterateImageVersions(imageName) {
  let result = [];
  let params = {
    owner: "Self",
    filters: [
      {
        name: "name",
        values: [imageName]
      }
    ]
  };
  while (true) {
    const response = await ib.listImages(params).promise();
    if (response.imageVersionList) {
      for (const imageVersion of response.imageVersionList) {
        if (imageVersion.arn) {
          result.push(imageVersion.arn);
        }
      }
    }
    if (!response.nextToken) {
      break;
    }
    params.nextToken = response.nextToken;
  }
  return result;
}
async function iterateImageBuildVersions(imageVersionArn) {
  var _a;
  let result = [];
  let params = {
    imageVersionArn
  };
  while (true) {
    const response = await ib.listImageBuildVersions(params).promise();
    if (response.imageSummaryList) {
      for (const imageBuildVersion of response.imageSummaryList) {
        if (((_a = imageBuildVersion.state) == null ? void 0 : _a.status) !== "AVAILABLE") {
          console.log(`${imageBuildVersion.arn} is still being created, so we can't delete it`);
          continue;
        }
        result.push(imageBuildVersion);
      }
    }
    if (!response.nextToken) {
      break;
    }
    params.nextToken = response.nextToken;
  }
  return result;
}
async function amisGone(amis) {
  var _a;
  if (!amis) {
    console.log("No AMIs found, so we can delete the image version build");
    return true;
  }
  for (const ami of amis) {
    console.log(`Checking if ${ami.image} exists`);
    if (!ami.image) {
      console.log("No AMI, so we can delete it");
      continue;
    }
    try {
      const response = await ec2.describeImages({
        ImageIds: [ami.image]
      }).promise();
      if (((_a = response.Images) == null ? void 0 : _a.length) ?? 0 > 0) {
        console.log("AMI still available, so we can't delete it");
        return false;
      }
    } catch (e) {
      if (e.code != "InvalidAMIID.NotFound") {
        console.error(`Unknown exception while checking if ${ami.image} exists:`, e);
        return false;
      }
    }
  }
  console.log("All AMIs are gone, so we can delete the image version build");
  return true;
}
async function dockerImagesGone(dockerImages) {
  var _a;
  if (!dockerImages) {
    console.log("No docker images, so we can delete the image version build");
    return true;
  }
  for (const images of dockerImages) {
    for (const image of images.imageUris ?? []) {
      const [repo, version] = image.split(":", 2);
      const [_, repoName] = repo.split("/", 2);
      if (version === "latest") {
        continue;
      }
      console.log(`Checking if ${repoName}:${version} exists`);
      try {
        const response = await ecr.describeImages({
          repositoryName: repoName,
          imageIds: [{ imageTag: version }]
        }).promise();
        if (response.imageDetails && response.imageDetails.length > 0) {
          if ((_a = response.imageDetails[0].imageTags) == null ? void 0 : _a.includes("latest")) {
            console.log(`Docker image ${repoName}:${version} still available and tagged latest, so we can't delete it`);
            return false;
          }
        }
      } catch (e) {
        if (e.code != "RepositoryNotFoundException" && e.code != "ImageNotFoundException") {
          console.error(`Unknown exception while checking if ${repoName}:${version} exists:`, e);
          return false;
        }
      }
    }
  }
  console.log("All Docker images are gone, so we can delete the image version build");
  return true;
}
exports.handler = async function(event, _context) {
  var _a, _b;
  for (const imageVersion of await iterateImageVersions(event.RecipeName)) {
    for (const imageBuildVersion of await iterateImageBuildVersions(imageVersion)) {
      if (!imageBuildVersion.arn) {
        continue;
      }
      console.log(`Checking ${imageBuildVersion.name}/${imageBuildVersion.version}`);
      if (await amisGone((_a = imageBuildVersion.outputResources) == null ? void 0 : _a.amis) && await dockerImagesGone((_b = imageBuildVersion.outputResources) == null ? void 0 : _b.containers)) {
        console.log("Deleting image version build", imageBuildVersion.arn);
        await ib.deleteImage({
          imageBuildVersionArn: imageBuildVersion.arn
        }).promise();
      }
    }
  }
};

==> cloudsnorkel.cdk_github_runners-0.11.6-py3-none-any.whl: package/assets/image-builders/aws-image-builder/reaper.lambda/index.js <==
"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/image-builders/aws-image-builder/reaper.lambda.ts
var reaper_lambda_exports = {};
__export(reaper_lambda_exports, {
  handler: () => handler
});
module.exports = __toCommonJS(reaper_lambda_exports);
var import_client_ec2 = require("@aws-sdk/client-ec2");
var import_client_ecr = require("@aws-sdk/client-ecr");
var import_client_imagebuilder = require("@aws-sdk/client-imagebuilder");
var ec2 = new import_client_ec2.EC2Client();
var ecr = new import_client_ecr.ECRClient();
var ib = new import_client_imagebuilder.ImagebuilderClient();
async function iterateImageVersions(imageName) {
  let result = [];
  let params = {
    owner: "Self",
    filters: [
      {
        name: "name",
        values: [imageName]
      }
    ]
  };
  while (true) {
    const response = await ib.send(new import_client_imagebuilder.ListImagesCommand(params));
    if (response.imageVersionList) {
      for (const imageVersion of response.imageVersionList) {
        if (imageVersion.arn) {
          result.push(imageVersion.arn);
        }
      }
    }
    if (!response.nextToken) {
      break;
    }
    params.nextToken = response.nextToken;
  }
  return result;
}
async function iterateImageBuildVersions(imageVersionArn) {
  let result = [];
  let params = {
    imageVersionArn
  };
  while (true) {
    const response = await ib.send(new import_client_imagebuilder.ListImageBuildVersionsCommand(params));
    if (response.imageSummaryList) {
      for (const imageBuildVersion of response.imageSummaryList) {
        if (imageBuildVersion.state?.status !== "AVAILABLE") {
          console.log(`${imageBuildVersion.arn} is still being created, so we can't delete it`);
          continue;
        }
        result.push(imageBuildVersion);
      }
    }
    if (!response.nextToken) {
      break;
    }
    params.nextToken = response.nextToken;
  }
  return result;
}
async function amisGone(amis) {
  if (!amis) {
    console.log("No AMIs found, so we can delete the image version build");
    return true;
  }
  for (const ami of amis) {
    console.log(`Checking if ${ami.image} exists`);
    if (!ami.image) {
      console.log("No AMI, so we can delete it");
      continue;
    }
    try {
      const response = await ec2.send(new import_client_ec2.DescribeImagesCommand({
        ImageIds: [ami.image]
      }));
      if (response.Images?.length ?? 0 > 0) {
        console.log("AMI still available, so we can't delete it");
        return false;
      }
    } catch (e) {
      if (e.code != "InvalidAMIID.NotFound") {
        console.error(`Unknown exception while checking if ${ami.image} exists:`, e);
        return false;
      }
    }
  }
  console.log("All AMIs are gone, so we can delete the image version build");
  return true;
}
async function dockerImagesGone(dockerImages) {
  if (!dockerImages) {
    console.log("No docker images, so we can delete the image version build");
    return true;
  }
  for (const images of dockerImages) {
    for (const image of images.imageUris ?? []) {
      const [repo, version] = image.split(":", 2);
      const [_, repoName] = repo.split("/", 2);
      if (version === "latest") {
        continue;
      }
      console.log(`Checking if ${repoName}:${version} exists`);
      try {
        const response = await ecr.send(new import_client_ecr.DescribeImagesCommand({
          repositoryName: repoName,
          imageIds: [{ imageTag: version }]
        }));
        if (response.imageDetails && response.imageDetails.length > 0) {
          if (response.imageDetails[0].imageTags?.includes("latest")) {
            console.log(`Docker image ${repoName}:${version} still available and tagged latest, so we can't delete it`);
            return false;
          }
        }
      } catch (e) {
        if (e.code != "RepositoryNotFoundException" && e.code != "ImageNotFoundException") {
          console.error(`Unknown exception while checking if ${repoName}:${version} exists:`, e);
          return false;
        }
      }
    }
  }
  console.log("All Docker images are gone, so we can delete the image version build");
  return true;
}
async function handler(event, _context) {
  for (const imageVersion of await iterateImageVersions(event.RecipeName)) {
    for (const imageBuildVersion of await iterateImageBuildVersions(imageVersion)) {
      if (!imageBuildVersion.arn) {
        continue;
      }
      console.log(`Checking ${imageBuildVersion.name}/${imageBuildVersion.version}`);
      if (await amisGone(imageBuildVersion.outputResources?.amis) && await dockerImagesGone(imageBuildVersion.outputResources?.containers)) {
        console.log("Deleting image version build", imageBuildVersion.arn);
        await ib.send(new import_client_imagebuilder.DeleteImageCommand({
          imageBuildVersionArn: imageBuildVersion.arn
        }));
      }
    }
  }
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  handler
});
